<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  記事情報登録用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBlog.pc.do
 */
class postInsertAction extends Pocket_Blog_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $entry_year    = $request['entry_year'];
        $entry_month   = $request['entry_month'];
        $entry_day     = $request['entry_day'];
        $entry_hour    = $request['entry_hour'];
        $entry_minute  = $request['entry_minute'];
        $author_name   = $request['author_name'];
        $subject       = $request['subject'];
        $category_id   = $request['category_id'];
        $is_open       = $request['is_open'];
        $allow_comment = $request['allow_comment'];
        $trackback_url = $request['trackback_url'];
        $body          = $request['body'];

        // 投稿日付情報の再生成(DB用)
        $r_datetime = date("Y-m-d H:i:s", mktime($entry_hour, $entry_minute, 0, $entry_month, $entry_day, $entry_year));

        // 記事の登録
        $post_id = db_insert_post($author_name, $subject, $category_id, $is_open, $allow_comment, $trackback_url, $body, $r_datetime);

        // 公開状態のチェック
        if ($is_open)
        {
            // トラックバックオブジェクトの生成
            $tb = new Pocket_Trackback();
            // トラックバック情報の送信
            $tb->send($trackback_url, BLOG_NAME, $subject, pocket_getSiteUrl() . '?m=pc&a=postComment.view&post_id=' . $post_id, $body);

            // PING自動送信機能がONの場合、バックグラウンドでPING送信を実行
            if (IS_PING_AUTO)
                system("php " . BASE_DIR . "../ping.php > /dev/null &");
        }

        // リダイレクト
        pocket_redirect('postComment.view', array('post_id' => $post_id));
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $entry_year    = $request['entry_year'];
        $entry_month   = $request['entry_month'];
        $entry_day     = $request['entry_day'];
        $entry_hour    = $request['entry_hour'];
        $entry_minute  = $request['entry_minute'];
        $author_name   = $request['author_name'];
        $subject       = $request['subject'];
        $category_id   = $request['category_id'];
        $is_open       = $request['is_open'];
        $allow_comment = $request['allow_comment'];
        $trackback_url = $request['trackback_url'];
        $body          = $request['body'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'postEntry';

        // 検証
        $validator->validate('entry_year'   , '投稿日付(年)'         , $entry_year   , 'number', true, 1980 ,2100);
        $validator->validate('entry_month'  , '投稿日付(月)'         , $entry_month  , 'number', true, 1 ,12);
        $validator->validate('entry_day'    , '投稿日付(日)'         , $entry_day    , 'number', true, 1 ,31);
        $validator->validate('entry_hour'   , '投稿日付(時)'         , $entry_hour   , 'number', true, 0 ,23);
        $validator->validate('entry_minute' , '投稿日付(分)'         , $entry_minute , 'number', true, 0 ,59);
        $validator->validate('author_name'  , '投稿者'               , $author_name  , 'string', true);
        $validator->validate('subject'      , 'タイトル'             , $subject      , 'string', true);
        $validator->validate('category_id'  , 'カテゴリ'             , $category_id  , 'number', true);
        $validator->validate('is_open'      , '公開状態'             , $is_open      , 'number', true);
        $validator->validate('allow_comment', 'コメント許可'         , $allow_comment, 'number', true);
        $validator->validate('trackback_url', 'トラックバック先のURL', $trackback_url, 'url');
        $validator->validate('body'         , '本文'                 , $body         , 'string', true);

        // 日付の検証(Validateの形式に合わせる)
        if ($validator->isValid() && !checkdate($entry_month, $entry_day, $entry_year))
        {
            $validator->addErrors('entry_date', '投稿日付が不正です。');
        }

    }

    /**
     *  認証アクションフラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isSecure()
    {
        return true;
    }
}

?>
